       
*CURRENT*
---
    
- 2019-11-28 (Laisky) fix: monotic time -> [view commit](https://github.com/Laisky/kipp/commit//7b0d0a0121f06fb7f9c0fea386ad30e92c6fe2d2)
- 2019-11-21 (Laisky) ci: release 0.2.7 -> [view commit](https://github.com/Laisky/kipp/commit//ef8608d3517dfc0ee1ae217f3aebf54e4c983837)
- 2019-11-21 (Laisky) style: format -> [view commit](https://github.com/Laisky/kipp/commit//67d8a3cb4a4c1675cdc3c26a05ccfa1afd3c00a9)
- 2019-11-08 (Laisky) ci: release 0.2.6 -> [view commit](https://github.com/Laisky/kipp/commit//76446528d2cb2cd307d74ca2a0535bd772f4d9e5)
- 2019-11-08 (Laisky) fix: 27 compatable issue -> [view commit](https://github.com/Laisky/kipp/commit//3f08ebb35cb2d85dcb803abd2cd12ebf39186a97)
- 2019-11-08 (Laisky) fix: 27 compatable issue -> [view commit](https://github.com/Laisky/kipp/commit//0031daf024b04be3764382f9a745cd95635d7956)
- 2019-11-08 (Laisky) style: format -> [view commit](https://github.com/Laisky/kipp/commit//09000859a14b69a3702b10a7d14019105bf4435b)
- 2019-08-22 (Laisky) fix: log contains more info -> [view commit](https://github.com/Laisky/kipp/commit//4c013d3e5a8f7014b078464ab49856e4d250d31e)
- 2019-08-14 (Laisky) ci: release 0.2.5 -> [view commit](https://github.com/Laisky/kipp/commit//9d0ef176629f18a4fd52bc2ef25e019f7be4317c)
- 2019-08-14 (Laisky) fix: timeout_cache bug -> [view commit](https://github.com/Laisky/kipp/commit//24132687246bd820111343ece49987f2b98148a6)
- 2019-08-05 (Laisky) ci: release 0.2.4 -> [view commit](https://github.com/Laisky/kipp/commit//2bc5bda6e7f593f89be662f46fed350c9daabded)
- 2019-08-05 (Laisky) fix: tornado req -> [view commit](https://github.com/Laisky/kipp/commit//841fc8400d2e6739a7fd0a8781d39da057da698f)
- 2019-07-26 (Laisky) build: reduce requirements -> [view commit](https://github.com/Laisky/kipp/commit//8dac88c6ee511de33731926b34ac170eb6e6e418)
- 2019-07-26 (Laisky) perf: reduce check frequency for timeout_cache -> [view commit](https://github.com/Laisky/kipp/commit//a9dff7f9fc0b854cf0a2824b3016a732671ba545)
- 2019-07-26 (Laisky) ci: release 0.2.3 -> [view commit](https://github.com/Laisky/kipp/commit//6d44db6bc3ffc9bffc5928a6c29f720bc1833e09)
- 2019-07-26 (Laisky) fix: timeout_cache args aware -> [view commit](https://github.com/Laisky/kipp/commit//ebd238685ba18dd120d002504ab2ed9c0a1f9da5)
- 2019-07-25 (Laisky) ci: release 0.2.2 -> [view commit](https://github.com/Laisky/kipp/commit//8c47bc8bcb000434ad031722ffbec963c844a1c9)
- 2019-07-25 (Laisky) feat: add `timeout_cache` -> [view commit](https://github.com/Laisky/kipp/commit//771aaf13ad5289f3f620c0a02fb082bd144089e5)
- 2019-07-25 (Laisky) ci: release 0.2.1 -> [view commit](https://github.com/Laisky/kipp/commit//77590006d26580d9284623bb4f054b8df68ecb27)
- 2019-07-25 (Laisky) docs: update licence -> [view commit](https://github.com/Laisky/kipp/commit//9f0abaf5185713d6cf65f5fb2821c2ad9a2e56c6)
- 2019-07-25 (Laisky) ci: release 0.2 -> [view commit](https://github.com/Laisky/kipp/commit//feddb393fda8f97ef5681f15ab1d8d2c01fcaac4)
- 2019-07-25 (Laisky) feat: opt support children options -> [view commit](https://github.com/Laisky/kipp/commit//2cc9c60814baa538b8b409589cdc51da1c2ded7c)
- 2019-07-17 (Laisky) ci: release 0.1.5 -> [view commit](https://github.com/Laisky/kipp/commit//621dd00895df0b8870dcb3f5b681265a008934db)
- 2019-07-17 (Laisky) fix: py3 conflict with `futures` -> [view commit](https://github.com/Laisky/kipp/commit//60188c44bc381c23d46c796db9f132e71485326f)
- 2018-11-05 (Laisky) docs: update readme -> [view commit](https://github.com/Laisky/kipp/commit//372f27464e22912d0dd639b5e618d078222a46fe)    
       
*0.1.4*
---
    
- 2019-06-13 (Laisky) ci: release 0.1.4 -> [view commit](https://github.com/Laisky/kipp/commit//337d50ea001eb9f143b453e33686fa2d8cf6e7c3)
- 2019-06-13 (Laisky) docs: update readme -> [view commit](https://github.com/Laisky/kipp/commit//32d9d23b54191dfa058b00202f16bd4d96ff1b81)
- 2019-06-13 (Laisky) fix: compatable to windows -> [view commit](https://github.com/Laisky/kipp/commit//5d4cee7c79f9f7509cb268b0f64bfc684626f9e6)
- 2018-11-05 (Laisky) 0.1.3 -> [view commit](https://github.com/Laisky/kipp/commit//2ab7b04926e086ab573551228474065764b1b796)
- 2018-11-05 (Laisky) fix: typo -> [view commit](https://github.com/Laisky/kipp/commit//7bba38cd10f5890fd500fe3d3b83b2c4c6524f07)
- 2018-08-02 (Laisky) fix: requirements -> [view commit](https://github.com/Laisky/kipp/commit//c0af07b2671ad80533609c29442477e7d8f5c5cb)
- 2018-06-28 (Laisky) ci: changelog -> [view commit](https://github.com/Laisky/kipp/commit//2e7f2f624c3b9a1c3c47bb5bf876df4f98e6cd8c)
- 2018-06-28 (Laisky) fix: compatible to pip v10 -> [view commit](https://github.com/Laisky/kipp/commit//e5b56e1fec1752dc476e38642b1fe1f7bcba8648)
- 2018-03-07 (Laisky) ci: changelog -> [view commit](https://github.com/Laisky/kipp/commit//2e8047664898c9872d4ed04407eaf520f5bcc3d0)
- 2018-03-07 (Laisky) fix: add `set_logger` -> [view commit](https://github.com/Laisky/kipp/commit//5b6938ee987c87e4baefce19b614ff4a2ce3aa26)
- 2018-02-26 (Laisky) fix: add `use_tls=True` to EmailSender -> [view commit](https://github.com/Laisky/kipp/commit//4d1340eab8d7a26d47431ed20a7d35b0b925987b)
- 2017-12-15 (Laisky) docs: index page error -> [view commit](https://github.com/Laisky/kipp/commit//447150927c760585179ff911aabc99238562aa13)
- 2017-12-15 (Laisky) ci: changelog -> [view commit](https://github.com/Laisky/kipp/commit//2429a3adc49167e4dc492e4e74c51b5daccd36f1)
- 2017-12-15 (Laisky) feat: add ''DFAFilter'' -> [view commit](https://github.com/Laisky/kipp/commit//9e386a289d0c5ed0f3c0333b792502aa36c45e61)
- 2017-11-07 (Laisky) ci: changelog -> [view commit](https://github.com/Laisky/kipp/commit//436e722efdc0fd6075ae918122fd38c040fe22b2)
- 2017-11-07 (Laisky) fix: remove some movoto functions -> [view commit](https://github.com/Laisky/kipp/commit//ea409470b7f2ca7e67bb64a539b2f2379751da1f)
- 2017-11-07 (Laisky) fix: EmailSender support username and passwd -> [view commit](https://github.com/Laisky/kipp/commit//dd6ddd842cd3fe608b7aecfb1eb6987ba6b9a331)
- 2017-11-07 (Laisky) ci: changelog -> [view commit](https://github.com/Laisky/kipp/commit//b1d726eabb088133b3b9dfe3c9c1e05db94c8a51)
- 2017-11-07 (Laisky) chore(change license): -> [view commit](https://github.com/Laisky/kipp/commit//868910994e5d5cbe2885196b9054be2384fd8f25)    
